__version__ = "0.1.3"

import pandas as pd
import os
import cv2
import argparse
from matplotlib import pyplot as plt

def show_images_from_cluster(excel_path, image_folder, cluster_id, num_images=5):
    df = pd.read_excel(excel_path)
    cluster_images = df[df['Cluster'] == cluster_id]['ISIN'].tolist()[:num_images]

    if not cluster_images:
        print(f"No images found for Cluster {cluster_id}!")
        return
    
    fig, axes = plt.subplots(1, len(cluster_images), figsize=(15, 5))
    if len(cluster_images) == 1:
        axes = [axes]  

    for ax, image_name in zip(axes, cluster_images):
        image_path = os.path.join(image_folder, image_name)
        if os.path.exists(image_path):
            img = cv2.imread(image_path)
            img = cv2.cvtColor(img, cv2.COLOR_BGR2RGB)
            ax.imshow(img)
            ax.set_title(image_name)
            ax.axis("off")
        else:
            print(f"❌ Image not found: {image_path}")

    plt.show()

def main():
    parser = argparse.ArgumentParser(description="Display images from a specific cluster.")
    parser.add_argument("excel_path", help="Path to the Excel file containing clustering results.")
    parser.add_argument("image_folder", help="Path to the folder containing images.")
    parser.add_argument("cluster_id", type=int, help="Cluster ID to display.")
    parser.add_argument("--num_images", type=int, default=5, help="Number of images to display.")

    args = parser.parse_args()
    show_images_from_cluster(args.excel_path, args.image_folder, args.cluster_id, args.num_images)

if __name__ == "__main__":
    main()
